-- Copyright (c) 2013-18 rubenwardy. MIT.

local S = awards.translator

minetest.register_privilege("awards_admin", { description = S("Can manage awards of given player") })

minetest.register_chatcommand("awards", {
	params = "[c|clear|disable|enable] [player_name]",
	description = S("Show, clear, disable or enable player's awards"),
	func = function(name, param)
		if not minetest.check_player_privs(name, { awards_admin = true }) then
			return false, S("You need awards_admin privilege!")
		end
		local action, playern = param:split(" ")[1], param:split(" ")[2] or name
		if action == "clear" then
			awards.clear_player(playern)
			minetest.chat_send_player(playern,
				S("All your awards and statistics have been cleared. You can now start again."))
			minetest.chat_send_player(name, S("All awards and statistics of @1 have been cleared.", playern))
		elseif action == "disable" then
			awards.disable(playern)
			minetest.chat_send_player(playern, S("Your awards are disabled."))
			minetest.chat_send_player(name, S("You have disabled awards of @1.", playern))
		elseif action == "enable" then
			awards.enable(playern)
			minetest.chat_send_player(playern, S("Your awards are enabled."))
			minetest.chat_send_player(name, S("You have enabled awards of @1.", playern))
		elseif action == "c" then
			awards.show_to(playern, name, nil, true)
		elseif not action then
			awards.show_to(name, name, nil, false)
		else
			awards.show_to(action, name, nil, true)
		end

		if (action == "disable" or action == "enable") and minetest.global_exists("sfinv") and not minetest.get_modpath("unified_inventory") then
			local player = minetest.get_player_by_name(playern)
			if player then
				sfinv.set_player_inventory_formspec(player)
			end
		end
	end
})

minetest.register_chatcommand("awd", {
	params = S("<award ID>"),
	description = S("Show details of an award"),
	func = function(name, param)
		local def = awards.registered_awards[param]
		if def then
			minetest.chat_send_player(name, string.format("%s: %s", def.title, def.description))
		else
			minetest.chat_send_player(name, S("Award not found."))
		end
	end
})

minetest.register_chatcommand("awpl", {
	privs = {
		server = true
	},
	params = S("<name>"),
	description = S("Get the awards statistics for the given player or yourself"),
	func = function(name, param)
		if not param or param == "" then
			param = name
		end
		minetest.chat_send_player(name, param)
		local player = awards.player(param)
		minetest.chat_send_player(name, dump(player))
	end
})
